package com.ruoyi.app.service;

import com.ruoyi.app.domain.AppTaskBak;

import java.util.List;

/**
 * 【请填写功能名称】Service接口
 *
 * @author ruoyi
 * @date 2025-01-15
 */
public interface IAppTaskBakService
{
    /**
     * 查询【请填写功能名称】
     *
     * @param taskId 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
    public AppTaskBak selectAppTaskBakByTaskId(String taskId);

    /**
     * 查询【请填写功能名称】列表
     *
     * @param appTaskBak 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<AppTaskBak> selectAppTaskBakList(AppTaskBak appTaskBak);

    /**
     * 新增【请填写功能名称】
     *
     * @param appTaskBak 【请填写功能名称】
     * @return 结果
     */
    public int insertAppTaskBak(AppTaskBak appTaskBak);

    /**
     * 修改【请填写功能名称】
     *
     * @param appTaskBak 【请填写功能名称】
     * @return 结果
     */
    public int updateAppTaskBak(AppTaskBak appTaskBak);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param taskIds 需要删除的【请填写功能名称】主键集合
     * @return 结果
     */
    public int deleteAppTaskBakByTaskIds(String[] taskIds);

    /**
     * 删除【请填写功能名称】信息
     *
     * @param taskId 【请填写功能名称】主键
     * @return 结果
     */
    public int deleteAppTaskBakByTaskId(String taskId);
}
